@@ -17,16 +17,30 @@ https://docs.pytest.org/en/reorganize-docs/new-docs/user/directory_structure.htm
 
 # ***************************************************************************************
 
-import pathlib as _pl
-import sys     as _sys
+class __:
+    '''<imports>'''
+
+    import pathlib as pl
+    import sys
+
+    # Insert project root as first directory to search in Python session PATH
+    sys.path.insert(0, (pl.Path(__file__).parent / "..").__str__())
 
-# Insert project root as first directory to search in Python session PATH
-_sys.path.insert(0, (_pl.Path(__file__).parent / "..").__str__())
 
 # ***************************************************************************************
 
-import lexer2
-import unittest
+# Application or library to test
+import lex2
 
-def DIR_OF(file: str) -> _pl.Path:
-    return _pl.Path(file).parent
+# Testing frameworks
+import unittest as ut
+import pytest   as pt
+
+
+# ***************************************************************************************
+#  Helper functions
+# ***************************************************************************************
+
+def dir_of(fp: str) -> __.pl.Path:
+    """Gets the directory path of a file."""
+    return __.pl.Path(fp).parent
